aboutsummaryrefslogtreecommitdiffstats
path: root/eth/protocol.go
diff options
context:
space:
mode:
Diffstat (limited to 'eth/protocol.go')
-rw-r--r--eth/protocol.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/eth/protocol.go b/eth/protocol.go
index bee3d8365..0e90e6a2e 100644
--- a/eth/protocol.go
+++ b/eth/protocol.go
@@ -103,9 +103,9 @@ type txPool interface {
// The slice should be modifiable by the caller.
Pending() (map[common.Address]types.Transactions, error)
- // SubscribeTxPreEvent should return an event subscription of
- // TxsPreEvent and send events to the given channel.
- SubscribeTxPreEvent(chan<- core.TxsPreEvent) event.Subscription
+ // SubscribeNewTxsEvent should return an event subscription of
+ // NewTxsEvent and send events to the given channel.
+ SubscribeNewTxsEvent(chan<- core.NewTxsEvent) event.Subscription
}
// statusData is the network packet for the status message.